@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -226,6 +226,10 @@ static LZWInfo *AcquireLZWInfo(Image *image,const size_t data_size)
       lzw_info=RelinquishLZWInfo(lzw_info);
       return((LZWInfo *) NULL);
     }
+  (void) ResetMagickMemory(lzw_info->table[0],0,MaximumLZWCode*
+    sizeof(**lzw_info->table));
+  (void) ResetMagickMemory(lzw_info->table[1],0,MaximumLZWCode*
+    sizeof(**lzw_info->table));
   for (i=0; i <= (ssize_t) lzw_info->maximum_data_value; i++)
   {
     lzw_info->table[0][i]=0;
@@ -414,7 +418,7 @@ static MagickBooleanType DecodeImage(Image *image,const ssize_t opacity)
     Allocate decoder tables.
   */
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   data_size=(unsigned char) ReadBlobByte(image);
@@ -888,7 +892,7 @@ static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
     block_count;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   assert(data != (unsigned char *) NULL);
   count=ReadBlob(image,1,&block_count);
   if (count != 1)
@@ -933,7 +937,7 @@ static MagickBooleanType PingGIFImage(Image *image)
     data_size;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (ReadBlob(image,1,&data_size) != 1)
@@ -967,9 +971,6 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
-  RectangleInfo
-    page;
-
   register ssize_t
     i;
 
@@ -977,12 +978,10 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *p;
 
   size_t
-    delay,
-    dispose,
     duration,
     global_colors,
     image_count,
-    iterations,
+    local_colors,
     one;
 
   ssize_t
@@ -1001,12 +1000,12 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Open image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
+  assert(exception->signature == MagickCoreSignature);
   image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -1022,8 +1021,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (LocaleNCompare((char *) magick,"GIF89",5) != 0)))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   (void) ResetMagickMemory(buffer,0,sizeof(buffer));
-  page.width=ReadBlobLSBShort(image);
-  page.height=ReadBlobLSBShort(image);
+  meta_image=AcquireImage(image_info);  /* metadata container */
+  meta_image->page.width=ReadBlobLSBShort(image);
+  meta_image->page.height=ReadBlobLSBShort(image);
   flag=(unsigned char) ReadBlobByte(image);
   background=(unsigned char) ReadBlobByte(image);
   c=(unsigned char) ReadBlobByte(image);  /* reserved */
@@ -1032,7 +1032,10 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   global_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
     MagickMax(global_colors,256),3UL*sizeof(*global_colormap));
   if (global_colormap == (unsigned char *) NULL)
-    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    {
+      meta_image=DestroyImage(meta_image);
+      ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    }
   (void) ResetMagickMemory(global_colormap,0,3*MagickMax(global_colors,256)*
     sizeof(*global_colormap));
   if (BitSet((int) flag,0x80) != 0)
@@ -1042,16 +1045,13 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           global_colormap=(unsigned char *) RelinquishMagickMemory(
             global_colormap);
+          meta_image=DestroyImage(meta_image);
           ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         }
     }
-  delay=0;
-  dispose=0;
   duration=0;
-  iterations=1;
   opacity=(-1);
   image_count=0;
-  meta_image=AcquireImage(image_info);  /* metadata container */
   for ( ; ; )
   {
     count=ReadBlob(image,1,&c);
@@ -1082,8 +1082,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               Read graphics control extension.
             */
             while (ReadBlobBlock(image,buffer) != 0) ;
-            dispose=(size_t) buffer[0] >> 2;
-            delay=((size_t) buffer[2] << 8) | buffer[1];
+            meta_image->dispose=(DisposeType) ((buffer[0] >> 2) & 0x07);
+            meta_image->delay=((size_t) buffer[2] << 8) | buffer[1];
             if ((ssize_t) (buffer[0] & 0x01) == 0x01)
               opacity=(ssize_t) buffer[3];
             break;
@@ -1127,9 +1127,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (loop != MagickFalse)
               while (ReadBlobBlock(image,buffer) != 0)
               {
-                iterations=((size_t) buffer[2] << 8) | buffer[1];
-                if (iterations != 0)
-                  iterations++;
+                meta_image->iterations=((size_t) buffer[2] << 8) | buffer[1];
+                if (meta_image->iterations != 0)
+                  meta_image->iterations++;
               }
             else
               {
@@ -1177,6 +1177,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     ThrowReaderException(ResourceLimitError,
                       "MemoryAllocationFailed");
                   }
+                (void) ResetMagickMemory(info,0,255UL*sizeof(*info));
                 reserved_length=255;
                 for (info_length=0; ; )
                 {
@@ -1261,6 +1262,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read image attributes.
     */
+    meta_image->page.x=(ssize_t) ReadBlobLSBShort(image);
+    meta_image->page.y=(ssize_t) ReadBlobLSBShort(image);
     meta_image->scene=image->scene;
     (void) CloneImageProperties(image,meta_image);
     DestroyImageProperties(meta_image);
@@ -1268,28 +1271,18 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     DestroyImageProfiles(meta_image);
     image->storage_class=PseudoClass;
     image->compression=LZWCompression;
-    page.x=(ssize_t) ReadBlobLSBShort(image);
-    page.y=(ssize_t) ReadBlobLSBShort(image);
     image->columns=ReadBlobLSBShort(image);
     image->rows=ReadBlobLSBShort(image);
     image->depth=8;
     flag=(unsigned char) ReadBlobByte(image);
     image->interlace=BitSet((int) flag,0x40) != 0 ? GIFInterlace : NoInterlace;
-    image->colors=BitSet((int) flag,0x80) == 0 ? global_colors : one <<
+    local_colors=BitSet((int) flag,0x80) == 0 ? global_colors : one <<
       ((size_t) (flag & 0x07)+1);
+    image->colors=local_colors;
     if (opacity >= (ssize_t) image->colors)
-      image->colors=opacity+1;
-    image->page.width=page.width;
-    image->page.height=page.height;
-    image->page.y=page.y;
-    image->page.x=page.x;
-    image->delay=delay;
-    image->iterations=iterations;
+      image->colors=(size_t) (opacity+1);
     image->ticks_per_second=100;
-    image->dispose=(DisposeType) dispose;
     image->matte=opacity >= 0 ? MagickTrue : MagickFalse;
-    delay=0;
-    dispose=0;
     if ((image->columns == 0) || (image->rows == 0))
       {
         global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1335,8 +1328,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read local colormap.
         */
-        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,3*
-          sizeof(*colormap));
+        colormap=(unsigned char *) AcquireQuantumMemory((size_t)
+          MagickMax(local_colors,256),3UL*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           {
             global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1344,8 +1337,10 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             meta_image=DestroyImage(meta_image);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        count=ReadBlob(image,(3*image->colors)*sizeof(*colormap),colormap);
-        if (count != (ssize_t) (3*image->colors))
+        (void) ResetMagickMemory(colormap,0,3*MagickMax(local_colors,256)*
+          sizeof(*colormap));
+        count=ReadBlob(image,(3*local_colors)*sizeof(*colormap),colormap);
+        if (count != (ssize_t) (3*local_colors))
           {
             global_colormap=(unsigned char *) RelinquishMagickMemory(
               global_colormap);
@@ -1371,7 +1366,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (IsGrayPixel(image->colormap+i) == MagickFalse)
             break;
         (void) SetImageColorspace(image,i == (ssize_t) image->colors ?
-          GRAYColorspace : RGBColorspace);
+          LinearGRAYColorspace : RGBColorspace);
       }
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -1560,9 +1555,9 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
     Open output image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -1576,7 +1571,14 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   colormap=(unsigned char *) AcquireQuantumMemory(768UL,sizeof(*colormap));
   if ((global_colormap == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+    {
+      if (global_colormap != (unsigned char *) NULL)
+        global_colormap=(unsigned char *) RelinquishMagickMemory(
+          global_colormap);
+      if (colormap != (unsigned char *) NULL)
+        colormap=(unsigned char *) RelinquishMagickMemory(colormap);
+      ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+    }
   for (i=0; i < 768; i++)
     colormap[i]=(unsigned char) 0;
   /*
