@@ -17,7 +17,7 @@
 %                              January 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -179,7 +179,6 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
         break;
       }
       case '-':
-      case '.':
       case ',':
       case '+':
       case '0':
@@ -199,6 +198,18 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,ssize_t *x,
         p++;
         break;
       }
+      case '.':
+      {
+        p++;
+        flags|=DecimalValue;
+        break;
+      }
+      case ':':
+      {
+        p++;
+        flags|=AspectRatioValue;
+        break;
+      }
       default:
         return(flags);
     }
@@ -937,7 +948,6 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       case '8':
       case '9':
       case '/':
-      case ':':
       case 215:
       case 'e':
       case 'E':
@@ -951,6 +961,12 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         flags|=DecimalValue;
         break;
       }
+      case ':':
+      {
+        p++;
+        flags|=AspectRatioValue;
+        break;
+      }
       default:
         return(NoValue);
     }
@@ -1209,10 +1225,38 @@ MagickExport MagickStatusType ParseGravityGeometry(const Image *image,
       scale.y=geometry_info.sigma;
       if ((status & SigmaValue) == 0)
         scale.y=scale.x;
-      region_info->width=(size_t) MagickMax(floor((scale.x*image->columns/
-        100.0)+0.5),1.0);
-      region_info->height=(size_t) MagickMax(floor((scale.y*image->rows/
-        100.0)+0.5),1.0);
+      region_info->width=(size_t) floor((scale.x*image->columns/100.0)+0.5);
+      region_info->height=(size_t) floor((scale.y*image->rows/100.0)+0.5);
+    }
+  if ((flags & AspectRatioValue) != 0)
+    {
+      double
+        geometry_ratio,
+        image_ratio;
+
+      GeometryInfo
+        geometry_info;
+
+      /*
+        Geometry is a relative to image size and aspect ratio.
+      */
+      if (image->gravity != UndefinedGravity)
+        flags|=XValue | YValue;
+      (void) ParseGeometry(geometry,&geometry_info);
+      geometry_ratio=geometry_info.rho;
+      image_ratio=image->columns/(double) image->rows;
+      if (geometry_ratio >= image_ratio)
+        {
+          region_info->width=image->columns;
+          region_info->height=(size_t) floor((image->rows*image_ratio/
+            geometry_ratio)+0.5);
+        }
+      else
+        {
+          region_info->width=(size_t) floor((image->columns*geometry_ratio/
+            image_ratio)+0.5);
+          region_info->height=image->rows;
+        }
     }
   /*
     Adjust offset according to gravity setting.
@@ -1325,6 +1369,35 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       former_width=(*width);
       former_height=(*height);
     }
+  if ((flags & AspectRatioValue) != 0)
+    {
+      double
+        geometry_ratio,
+        image_ratio;
+
+      GeometryInfo
+        geometry_info;
+
+      /*
+        Geometry is a relative to image size and aspect ratio.
+      */
+      (void) ParseGeometry(geometry,&geometry_info);
+      geometry_ratio=geometry_info.rho;
+      image_ratio=former_width/(double) former_height;
+      if (geometry_ratio >= image_ratio)
+        {
+          *width=former_width;
+          *height=(size_t) floor((former_height*image_ratio/geometry_ratio)+
+            0.5);
+        }
+      else
+        {
+          *width=(size_t) floor((former_width*geometry_ratio/image_ratio)+0.5);
+          *height=former_height;
+        }
+      former_width=(*width);
+      former_height=(*height);
+    }
   if (((flags & AspectValue) != 0) || ((*width == former_width) &&
       (*height == former_height)))
     {
@@ -1560,7 +1633,7 @@ MagickExport MagickStatusType ParseRegionGeometry(const Image *image,
 MagickExport void SetGeometry(const Image *image,RectangleInfo *geometry)
 {
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(geometry != (RectangleInfo *) NULL);
