@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -171,7 +171,7 @@ MagickExport StreamInfo *AcquireStreamInfo(const ImageInfo *image_info)
   stream_info->map=ConstantString("RGB");
   stream_info->storage_type=CharPixel;
   stream_info->stream=AcquireImage(image_info);
-  stream_info->signature=MagickSignature;
+  stream_info->signature=MagickCoreSignature;
   return(stream_info);
 }
 
@@ -220,11 +220,11 @@ static void DestroyPixelStream(Image *image)
     destroy;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   destroy=MagickFalse;
   LockSemaphoreInfo(cache_info->semaphore);
   cache_info->reference_count--;
@@ -271,7 +271,7 @@ MagickExport StreamInfo *DestroyStreamInfo(StreamInfo *stream_info)
 {
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   if (stream_info->map != (char *) NULL)
     stream_info->map=DestroyString(stream_info->map);
   if (stream_info->pixels != (unsigned char *) NULL)
@@ -284,7 +284,7 @@ MagickExport StreamInfo *DestroyStreamInfo(StreamInfo *stream_info)
     }
   if (stream_info->quantum_info != (QuantumInfo *) NULL)
     stream_info->quantum_info=DestroyQuantumInfo(stream_info->quantum_info);
-  stream_info->signature=(~MagickSignature);
+  stream_info->signature=(~MagickCoreSignature);
   stream_info=(StreamInfo *) RelinquishMagickMemory(stream_info);
   return(stream_info);
 }
@@ -318,11 +318,11 @@ static IndexPacket *GetAuthenticIndexesFromStream(const Image *image)
     *cache_info;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   return(cache_info->indexes);
 }
 
@@ -366,7 +366,7 @@ static PixelPacket *GetAuthenticPixelsStream(Image *image,const ssize_t x,
     *pixels;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   pixels=QueueAuthenticPixelsStream(image,x,y,columns,rows,exception);
@@ -402,11 +402,11 @@ static PixelPacket *GetAuthenticPixelsFromStream(const Image *image)
     *cache_info;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   return(cache_info->pixels);
 }
 
@@ -448,7 +448,7 @@ static MagickBooleanType GetOneAuthenticPixelFromStream(Image *image,
     *pixels;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   *pixel=image->background_color;
   pixels=GetAuthenticPixelsStream(image,x,y,1,1,exception);
   if (pixels == (PixelPacket *) NULL)
@@ -498,7 +498,7 @@ static MagickBooleanType GetOneVirtualPixelFromStream(const Image *image,
     *pixels;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   *pixel=image->background_color;
   pixels=GetVirtualPixelStream(image,virtual_pixel_method,x,y,1,1,exception);
   if (pixels == (const PixelPacket *) NULL)
@@ -532,7 +532,7 @@ static MagickBooleanType GetOneVirtualPixelFromStream(const Image *image,
 MagickExport const void *GetStreamInfoClientData(StreamInfo *stream_info)
 {
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   return(stream_info->client_data);
 }
 
@@ -568,11 +568,11 @@ static const PixelPacket *GetVirtualPixelsStream(const Image *image)
     *cache_info;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   return(cache_info->pixels);
 }
 
@@ -605,11 +605,11 @@ static const IndexPacket *GetVirtualIndexesFromStream(const Image *image)
     *cache_info;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   return(cache_info->indexes);
 }
 
@@ -724,7 +724,7 @@ static const PixelPacket *GetVirtualPixelStream(const Image *image,
     Validate pixel cache geometry.
   */
   assert(image != (const Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if ((x < 0) || (y < 0) ||
@@ -737,7 +737,7 @@ static const PixelPacket *GetVirtualPixelStream(const Image *image,
       return((PixelPacket *) NULL);
     }
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   /*
     Pixels are stored in a temporary buffer until they are synced to the cache.
   */
@@ -886,7 +886,7 @@ static PixelPacket *QueueAuthenticPixelsStream(Image *image,const ssize_t x,
       return((PixelPacket *) NULL);
     }
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   if ((image->storage_class != GetPixelCacheStorageClass(image->cache)) ||
       (image->colorspace != GetPixelCacheColorspace(image->cache)))
     {
@@ -982,12 +982,12 @@ MagickExport Image *ReadStream(const ImageInfo *image_info,StreamHandler stream,
     Stream image pixels.
   */
   assert(image_info != (ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
+  assert(exception->signature == MagickCoreSignature);
   read_info=CloneImageInfo(image_info);
   read_info->cache=AcquirePixelCache(0);
   GetPixelCacheMethods(&cache_methods);
@@ -1040,7 +1040,7 @@ MagickExport void SetStreamInfoClientData(StreamInfo *stream_info,
   const void *client_data)
 {
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   stream_info->client_data=client_data;
 }
 
@@ -1071,7 +1071,7 @@ MagickExport void SetStreamInfoClientData(StreamInfo *stream_info,
 MagickExport void SetStreamInfoMap(StreamInfo *stream_info,const char *map)
 {
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   (void) CloneString(&stream_info->map,map);
 }
 
@@ -1104,7 +1104,7 @@ MagickExport void SetStreamInfoStorageType(StreamInfo *stream_info,
   const StorageType storage_type)
 {
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   stream_info->storage_type=storage_type;
 }
 
@@ -1174,7 +1174,7 @@ static size_t WriteStreamImage(const Image *image,const void *pixels,
     case ShortPixel: packet_size=sizeof(unsigned short); break;
   }
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   packet_size*=strlen(stream_info->map);
   length=packet_size*cache_info->columns*cache_info->rows;
   if (image != stream_info->image)
@@ -1242,16 +1242,21 @@ MagickExport Image *StreamImage(const ImageInfo *image_info,
     *read_info;
 
   assert(image_info != (const ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   assert(exception != (ExceptionInfo *) NULL);
   read_info=CloneImageInfo(image_info);
   stream_info->image_info=image_info;
   stream_info->quantum_info=AcquireQuantumInfo(image_info,(Image *) NULL);
+  if (stream_info->quantum_info == (QuantumInfo *) NULL)
+    {
+      read_info=DestroyImageInfo(read_info);
+      return((Image *) NULL);
+    }
   stream_info->exception=exception;
   read_info->client_data=(void *) stream_info;
   image=ReadStream(read_info,&WriteStreamImage,exception);
@@ -1315,9 +1320,9 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
     length;
 
   assert(stream_info != (StreamInfo *) NULL);
-  assert(stream_info->signature == MagickSignature);
+  assert(stream_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   length=strlen(stream_info->map);
@@ -2700,11 +2705,11 @@ static MagickBooleanType SyncAuthenticPixelsStream(Image *image,
     stream_handler;
 
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   cache_info=(CacheInfo *) image->cache;
-  assert(cache_info->signature == MagickSignature);
+  assert(cache_info->signature == MagickCoreSignature);
   stream_handler=GetBlobStreamHandler(image);
   if (stream_handler == (StreamHandler) NULL)
     {
@@ -2752,12 +2757,12 @@ MagickExport MagickBooleanType WriteStream(const ImageInfo *image_info,
     status;
 
   assert(image_info != (ImageInfo *) NULL);
-  assert(image_info->signature == MagickSignature);
+  assert(image_info->signature == MagickCoreSignature);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
   assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
+  assert(image->signature == MagickCoreSignature);
   write_info=CloneImageInfo(image_info);
   *write_info->magick='\0';
   write_info->stream=stream;
